######################
Time Series Aggregation Class
######################

.. |br| raw:: html

   <br />

Descriptions of the basic functions are given below.

**Function descriptions:**

.. automodule:: timeseriesaggregation
   :members: unstackToPeriods
   :member-order: bysource

   .. autoclass:: TimeSeriesAggregation
      :members:
      :member-order: bysource

      .. automethod:: __init__
